@@ -6,9 +6,8 @@ import (
 	"os/exec"
 	"sync"
 
-	"github.com/caarlos0/ctrlc"
 	"github.com/caarlos0/log"
-	"github.com/charmbracelet/lipgloss"
+	"github.com/charmbracelet/lipgloss/v2"
 	"github.com/goreleaser/goreleaser/v2/internal/middleware/skip"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/defaults"
 	"github.com/goreleaser/goreleaser/v2/pkg/context"
@@ -33,7 +32,7 @@ func newHealthcheckCmd() *healthcheckCmd {
 		SilenceErrors:     true,
 		Args:              cobra.NoArgs,
 		ValidArgsFunction: cobra.NoFileCompletions,
-		RunE: func(_ *cobra.Command, _ []string) error {
+		RunE: func(cmd *cobra.Command, _ []string) error {
 			if root.quiet {
 				log.Log = log.New(io.Discard)
 			}
@@ -42,42 +41,35 @@ func newHealthcheckCmd() *healthcheckCmd {
 			if err != nil {
 				return err
 			}
-			ctx := context.New(cfg)
+			ctx := context.Wrap(cmd.Context(), cfg)
 
-			if err := ctrlc.Default.Run(ctx, func() error {
-				log.Info(boldStyle.Render("checking tools..."))
+			log.Info(boldStyle.Render("checking tools..."))
 
-				err := defaults.Pipe{}.Run(ctx)
-				if err != nil {
-					return err
-				}
-
-				log.IncreasePadding()
-				defer log.ResetPadding()
-
-				var errs []error
-				for _, hc := range healthcheck.Healthcheckers {
-					_ = skip.Maybe(hc, func(ctx *context.Context) error {
-						for _, tool := range hc.Dependencies(ctx) {
-							if err := checkPath(tool); err != nil {
-								errs = append(errs, err)
-							}
-						}
-						return nil
-					})(ctx)
-				}
-
-				if len(errs) == 0 {
-					return nil
-				}
-
-				return errors.New("one or more needed tools are not present")
-			}); err != nil {
+			if err := (defaults.Pipe{}).Run(ctx); err != nil {
 				return err
 			}
 
-			log.Infof(boldStyle.Render("done!"))
-			return nil
+			log.IncreasePadding()
+			defer log.ResetPadding()
+
+			var errs []error
+			for _, hc := range healthcheck.Healthcheckers {
+				_ = skip.Maybe(hc, func(ctx *context.Context) error {
+					for _, tool := range hc.Dependencies(ctx) {
+						if err := checkPath(tool); err != nil {
+							errs = append(errs, err)
+						}
+					}
+					return nil
+				})(ctx)
+			}
+
+			if len(errs) == 0 {
+				log.Infof(boldStyle.Render("done!"))
+				return nil
+			}
+
+			return errors.New("one or more needed tools are not present")
 		},
 	}
 
