@@ -1,15 +1,20 @@
 package cmd
 
 import (
+	"cmp"
+	stdctx "context"
 	"errors"
 	"fmt"
+	"io"
+	"os"
 	"slices"
 	"time"
 
 	goversion "github.com/caarlos0/go-version"
 	"github.com/caarlos0/log"
-	"github.com/charmbracelet/lipgloss"
-	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/charmbracelet/fang"
+	"github.com/charmbracelet/lipgloss/v2"
+	"github.com/goreleaser/goreleaser/v2/internal/gerrors"
 	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/spf13/cobra"
 )
@@ -34,25 +39,29 @@ func (cmd *rootCmd) Execute(args []string) {
 		log.SetLevel(log.FatalLevel)
 	}
 
-	if err := cmd.cmd.Execute(); err != nil {
-		code := 1
-		msg := "command failed"
-		log := log.WithError(err)
-		eerr := &exitError{}
-		if errors.As(err, &eerr) {
-			code = eerr.code
-			if eerr.details != "" {
-				msg = eerr.details
-			}
-			for k, v := range pipe.DetailsOf(eerr.err) {
-				log = log.WithField(k, v)
-			}
-		}
-		log.Error(msg)
-		cmd.exit(code)
+	if err := fang.Execute(
+		stdctx.Background(),
+		cmd.cmd,
+		fang.WithVersion(cmd.cmd.Version),
+		fang.WithErrorHandler(errorHandler),
+		fang.WithColorSchemeFunc(fang.AnsiColorScheme),
+		fang.WithNotifySignal(os.Interrupt, os.Kill),
+	); err != nil {
+		cmd.exit(gerrors.ExitOf(err))
 	}
 }
 
+func errorHandler(_ io.Writer, _ fang.Styles, err error) {
+	log := log.WithError(err)
+	for k, v := range gerrors.DetailsOf(err) {
+		log = log.WithField(k, v)
+	}
+	log.Error(cmp.Or(
+		gerrors.MessageOf(err),
+		"command failed",
+	))
+}
+
 type rootCmd struct {
 	cmd     *cobra.Command
 	verbose bool
@@ -66,20 +75,33 @@ func newRootCmd(version goversion.Info, exit func(int)) *rootCmd {
 	cmd := &cobra.Command{
 		Use:   "goreleaser",
 		Short: "Release engineering, simplified",
-		Long: `GoReleaser is a release automation tool.
-Its goal is to simplify the build, release and publish steps while providing variant customization options for all steps.
+		Long: `Release engineering, simplified.
 
-GoReleaser is built for CI tools, you only need to download and execute it in your build script. Of course, you can also install it locally if you wish.
+GoReleaser is a release automation tool, built with love and care by @caarlos0 and many contributors.
 
-You can customize your entire release process through a single .goreleaser.yaml file.
-
-Check out our website for more information, examples and documentation: https://goreleaser.com
-`,
+Complete documentation is available at https://goreleaser.com`,
 		Version:           version.String(),
-		SilenceUsage:      true,
-		SilenceErrors:     true,
 		Args:              cobra.NoArgs,
 		ValidArgsFunction: cobra.NoFileCompletions,
+		Example: `
+# Initialize your project:
+goreleaser init
+
+# Verify your configuration:
+goreleaser check
+
+# Verify dependencies:
+goreleaser healthcheck
+
+# Build the binaries only:
+goreleaser build
+
+# Run a snapshot release:
+goreleaser release --snapshot
+
+# Run a complete release:
+goreleaser release
+		`,
 		PersistentPreRun: func(*cobra.Command, []string) {
 			if root.verbose {
 				log.SetLevel(log.DebugLevel)
@@ -102,6 +124,7 @@ Check out our website for more information, examples and documentation: https://
 		newDocsCmd().cmd,
 		newManCmd().cmd,
 		newSchemaCmd().cmd,
+		newMcpCmd(version).cmd,
 	)
 	root.cmd = cmd
 	return root
@@ -147,15 +170,16 @@ func deprecateWarn(ctx *context.Context) {
 	}
 }
 
-func timedRunE(verb string, runE func(cmd *cobra.Command, args []string) error) func(cmd *cobra.Command, args []string) error {
-	return func(cmd *cobra.Command, args []string) error {
-		start := time.Now()
+func after(start time.Time) time.Duration {
+	return time.Since(start).Truncate(time.Second)
+}
 
-		if err := runE(cmd, args); err != nil {
-			return wrapError(err, boldStyle.Render(fmt.Sprintf("%s failed after %s", verb, time.Since(start).Truncate(time.Second))))
-		}
-
-		log.Infof(boldStyle.Render(fmt.Sprintf("%s succeeded after %s", verb, time.Since(start).Truncate(time.Second))))
-		return nil
+func decorateWithCtxErr(ctx stdctx.Context, err error, verb string, after time.Duration) error {
+	if errors.Is(ctx.Err(), stdctx.Canceled) {
+		return gerrors.Wrap(ctx.Err(), fmt.Sprintf("%s interrupted after %s", verb, after))
+	}
+	if errors.Is(ctx.Err(), stdctx.DeadlineExceeded) {
+		return gerrors.Wrap(ctx.Err(), fmt.Sprintf("%s timed out after %s", verb, after))
 	}
+	return gerrors.Wrap(err, fmt.Sprintf("%s failed after %s", verb, after))
 }
