@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"slices"
 	"testing"
 
 	"github.com/goreleaser/goreleaser/v2/internal/golden"
@@ -66,6 +67,11 @@ func TestFilter(t *testing.T) {
 			Goos:   "linux",
 			Goarch: "arm",
 		},
+		{
+			Name:   "foo",
+			Goos:   "darwin",
+			Goarch: "arm64",
+		},
 		{
 			Name:    "bar",
 			Goarch:  "amd64",
@@ -130,7 +136,7 @@ func TestFilter(t *testing.T) {
 	}
 
 	require.Len(t, artifacts.Filter(ByGoos("linux")).items, 1)
-	require.Len(t, artifacts.Filter(ByGoos("darwin")).items, 2)
+	require.Len(t, artifacts.Filter(ByGoos("darwin")).items, 3)
 
 	require.Len(t, artifacts.Filter(ByGoarch("amd64")).items, 5)
 	require.Empty(t, artifacts.Filter(ByGoarch("386")).items)
@@ -146,10 +152,11 @@ func TestFilter(t *testing.T) {
 	require.Len(t, artifacts.Filter(ByType(Checksum)).items, 2)
 	require.Empty(t, artifacts.Filter(ByType(Binary)).items)
 
-	require.Len(t, artifacts.Filter(OnlyReplacingUnibins).items, 11)
-	require.Len(t, artifacts.Filter(And(OnlyReplacingUnibins, ByGoos("darwin"))).items, 1)
+	require.Len(t, artifacts.Filter(OnlyReplacingUnibins).items, 12)
+	require.Len(t, artifacts.Filter(And(OnlyReplacingUnibins, ByGoos("darwin"))).items, 2)
+	require.Len(t, artifacts.Filter(And(Not(ByGoos("linux")), ByGoarch("arm64"))).items, 1)
 
-	require.Len(t, artifacts.Filter(nil).items, 12)
+	require.Len(t, artifacts.Filter(nil).items, 13)
 
 	require.Len(t, artifacts.Filter(
 		And(
@@ -379,6 +386,35 @@ func TestGroupByPlatform_mixingBuilders(t *testing.T) {
 	require.Len(t, groups["linuxarm"], 2)
 }
 
+func TestGroupByPlatform_abi(t *testing.T) {
+	data := []*Artifact{
+		{
+			Name:   "foo",
+			Goos:   "linux",
+			Goarch: "amd64",
+			Extra: map[string]any{
+				"Abi": "musl",
+			},
+		},
+		{
+			Name:   "foo",
+			Goos:   "linux",
+			Goarch: "amd64",
+			Extra: map[string]any{
+				"Abi": "gnu",
+			},
+		},
+	}
+	artifacts := New()
+	for _, a := range data {
+		artifacts.Add(a)
+	}
+	groups := artifacts.GroupByPlatform()
+	require.Len(t, groups, 2)
+	require.Len(t, groups["linuxamd64musl"], 1)
+	require.Len(t, groups["linuxamd64gnu"], 1)
+}
+
 func TestChecksum(t *testing.T) {
 	folder := t.TempDir()
 	file := filepath.Join(folder, "subject")
@@ -411,6 +447,21 @@ func TestChecksum(t *testing.T) {
 	}
 }
 
+func TestChecksumSetArtifactExtra(t *testing.T) {
+	folder := t.TempDir()
+	file := filepath.Join(folder, "subject")
+	require.NoError(t, os.WriteFile(file, []byte("lorem ipsum"), 0o644))
+	artifact := Artifact{
+		Path:  file,
+		Extra: nil,
+	}
+
+	sum, err := artifact.Checksum("crc32")
+	require.NoError(t, err)
+	require.Equal(t, "72d7748e", sum)
+	require.Equal(t, Extras{ExtraChecksum: "crc32:72d7748e"}, artifact.Extra)
+}
+
 func TestChecksumFileDoesntExist(t *testing.T) {
 	file := filepath.Join(t.TempDir(), "nope")
 	artifact := Artifact{
@@ -1008,7 +1059,7 @@ func TestArtifactStringer(t *testing.T) {
 }
 
 func TestArtifactTypeStringer(t *testing.T) {
-	for i := 1; i <= 30; i++ {
+	for i := 1; i < int(lastMarker); i++ {
 		t.Run(fmt.Sprintf("type-%d-%s", i, Type(i).String()), func(t *testing.T) {
 			require.NotEqual(t, "unknown", Type(i).String())
 		})
@@ -1018,3 +1069,27 @@ func TestArtifactTypeStringer(t *testing.T) {
 		require.Equal(t, "unknown", Type(99999).String())
 	})
 }
+
+func TestArtifactTypeIsUploadable(t *testing.T) {
+	nonUploadable := []Type{
+		Binary,
+		Metadata,
+		SrcInfo,
+		SourceSrcInfo,
+		PkgBuild,
+		SourcePkgBuild,
+		UniversalBinary,
+		DockerImage,
+		Snapcraft,
+	}
+	for i := range lastMarker - 1 {
+		up := i.isUploadable()
+		t.Run(fmt.Sprintf("%s-%v", i.String(), up), func(t *testing.T) {
+			if slices.Contains(nonUploadable, i) {
+				require.False(t, up)
+				return
+			}
+			require.True(t, up)
+		})
+	}
+}
