@@ -9,8 +9,10 @@ import (
 	"github.com/goreleaser/goreleaser/v2/internal/middleware/skip"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/artifactory"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/aur"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/aursources"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/blob"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/brew"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/cask"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/chocolatey"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/custompublishers"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/docker"
@@ -43,7 +45,6 @@ func New() Pipe {
 			blob.Pipe{},
 			upload.Pipe{},
 			artifactory.Pipe{},
-			custompublishers.Pipe{},
 			docker.Pipe{},
 			docker.ManifestPipe{},
 			ko.Pipe{},
@@ -52,14 +53,17 @@ func New() Pipe {
 			// This should be one of the last steps
 			release.Pipe{},
 			// brew et al use the release URL, so, they should be last
-			nix.NewPublish(),
+			nix.New(),
 			winget.Pipe{},
 			brew.Pipe{},
+			cask.Pipe{},
 			aur.Pipe{},
+			aursources.Pipe{},
 			krew.Pipe{},
 			scoop.Pipe{},
 			chocolatey.Pipe{},
 			milestone.Pipe{},
+			custompublishers.Pipe{},
 		},
 	}
 }
